@@ -7,5 +7,5 @@ def checkWifi(name):
     if not name: return False
     if type(name) == str: name = [name]
     command = ['/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport', '-I']
-    res = subprocess.check_output(command)
-    return any(re.search(re.compile('SSID: %s\n' % item), res) for item in name)
\ No newline at end of file
+    res = subprocess.check_output(command).decode('utf-8')
+    return any(re.search(re.compile('SSID: %s\n' % item), res) for item in name)
