@@ -1,7 +1,7 @@
 # coding: utf-8
 import os
 import sys
-from dotenv import load_dotenv, set_key
+from dotenv import load_dotenv, set_key, unset_key
 from .logger import Logger
 
 logger = Logger('enver').getLogger()
@@ -18,7 +18,7 @@ def enver(file):
     def getenv(key):
         '''返回env中对应key的值'''
         return os.environ.get(str(key))
-    def setenv(key, val):
+    def setenv(key, val = None):
         '''设置env中对应key的值'''
         if not val:
             os.environ.pop(key)
